@@ -333,7 +333,7 @@ nice_socket_queue_send (GQueue *send_queue, const NiceAddress *to,
       offset += len;
     }
 
-    g_assert_cmpint (offset, ==, tbs->length);
+    g_assert (offset == tbs->length);
   }
 }
 
@@ -453,3 +453,32 @@ nice_socket_free_send_queue (GQueue *send_queue)
   g_list_free_full (send_queue->head, (GDestroyNotify) nice_socket_free_queued_send);
   g_queue_init (send_queue);
 }
+
+const gchar *
+nice_socket_type_to_string (NiceSocketType type)
+{
+  switch (type) {
+    case NICE_SOCKET_TYPE_UDP_BSD:
+      return "udp";
+    case NICE_SOCKET_TYPE_TCP_BSD:
+      return "tcp";
+    case NICE_SOCKET_TYPE_PSEUDOSSL:
+      return "ssl";
+    case NICE_SOCKET_TYPE_HTTP:
+      return "http";
+    case NICE_SOCKET_TYPE_SOCKS5:
+      return "socks";
+    case NICE_SOCKET_TYPE_UDP_TURN:
+      return "udp-turn";
+    case NICE_SOCKET_TYPE_UDP_TURN_OVER_TCP:
+      return "tcp-turn";
+    case NICE_SOCKET_TYPE_TCP_ACTIVE:
+      return "tcp-act";
+    case NICE_SOCKET_TYPE_TCP_PASSIVE:
+      return "tcp-pass";
+    case NICE_SOCKET_TYPE_TCP_SO:
+      return "tcp-so";
+    default:
+      return "<unknown>";
+  }
+}
