@@ -140,7 +140,7 @@ static const uint32_t crc32_tab[] = {
 };
 
 
-uint32_t crc32 (const crc_data *data, size_t n, bool wlm2009_stupid_crc32_typo)
+uint32_t stun_crc32 (const crc_data *data, size_t n, bool wlm2009_stupid_crc32_typo)
 {
   size_t i;
   uint32_t crc = 0xffffffff;
